@@ -12,10 +12,3 @@ close(fileConn)
 # build vignettes
 library("devtools")
 build_vignettes()
-
-# move resource files to /doc
-resources <-
-  list.files("vignettes/", pattern = ".png$", full.names = TRUE)
-file.copy(from = resources,
-          to = "doc",
-          overwrite =  TRUE)
